==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/Session.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Session extends BusinessEntity {     String EXT_SESSION = "Session";
     String FIELD_SESSION_SESSIONDATE = "sessionDate";
     String FQ_FIELD_SESSION_SESSIONDATE = EXT_SESSION + ".sessionDate";
     String FIELD_SESSION_NUM = "num";
     String FQ_FIELD_SESSION_NUM = EXT_SESSION + ".num";
     String FIELD_SESSION_STATUS = "status";
     String FQ_FIELD_SESSION_STATUS = EXT_SESSION + ".status";
     String FIELD_SESSION_PARAGRAPH = "paragraph";
     String FQ_FIELD_SESSION_PARAGRAPH = EXT_SESSION + ".paragraph";
     String FIELD_SESSION_SENDING = "sending";
     String FQ_FIELD_SESSION_SENDING = EXT_SESSION + ".sending";
    /**
     * getSessionDate :
     * @return Date 
     */

     Date getSessionDate();

    /**
     * setSessionDate :
     * @param sessionDate 
     */

     void setSessionDate(Date sessionDate);

    /**
     * getNum :
     * @return int 
     */

     int getNum();

    /**
     * setNum :
     * @param num 
     */

     void setNum(int num);

    /**
     * getStatus :
     * @return int 
     */

     int getStatus();

    /**
     * setStatus :
     * @param status 
     */

     void setStatus(int status);

    /**
     * getParagraph :
     * @return String 
     */

     String getParagraph();

    /**
     * setParagraph :
     * @param paragraph 
     */

     void setParagraph(String paragraph);

    /**
     * getSending :
     * @return Set<String> 
     */

     Set<String> getSending();

    /**
     * addSending :
     * @param element 
     */

     void addSending(String element);

    /**
     * removeSending :
     * @param element 
     */

     void removeSending(String element);

    /**
     * clearSending :
     */

     void clearSending();


} //Session

==> vradi-entities-0.4.0-sources.jar: com/jurismarches/vradi/entities/Session.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Session extends BusinessEntity {     String EXT_SESSION = "Session";
     String FIELD_SESSION_SESSIONDATE = "sessionDate";
     String FQ_FIELD_SESSION_SESSIONDATE = EXT_SESSION + ".sessionDate";
     String FIELD_SESSION_NUM = "num";
     String FQ_FIELD_SESSION_NUM = EXT_SESSION + ".num";
     String FIELD_SESSION_STATUS = "status";
     String FQ_FIELD_SESSION_STATUS = EXT_SESSION + ".status";
     String FIELD_SESSION_PARAGRAPH = "paragraph";
     String FQ_FIELD_SESSION_PARAGRAPH = EXT_SESSION + ".paragraph";
     String FIELD_SESSION_SESSIONLOGS = "sessionLogs";
     String FQ_FIELD_SESSION_SESSIONLOGS = EXT_SESSION + ".sessionLogs";
     String FIELD_SESSION_SENDING = "sending";
     String FQ_FIELD_SESSION_SENDING = EXT_SESSION + ".sending";
    /**
     * getSessionDate :
     * @return Date 
     */

     Date getSessionDate();

    /**
     * setSessionDate :
     * @param sessionDate 
     */

     void setSessionDate(Date sessionDate);

    /**
     * getNum :
     * @return int 
     */

     int getNum();

    /**
     * setNum :
     * @param num 
     */

     void setNum(int num);

    /**
     * getStatus :
     * @return int 
     */

     int getStatus();

    /**
     * setStatus :
     * @param status 
     */

     void setStatus(int status);

    /**
     * getParagraph :
     * @return String 
     */

     String getParagraph();

    /**
     * setParagraph :
     * @param paragraph 
     */

     void setParagraph(String paragraph);

    /**
     * getSessionLogs :
     * @return String 
     */

     String getSessionLogs();

    /**
     * setSessionLogs :
     * @param sessionLogs 
     */

     void setSessionLogs(String sessionLogs);

    /**
     * getSending :
     * @return Set<String> 
     */

     Set<String> getSending();

    /**
     * addSending :
     * @param element 
     */

     void addSending(String element);

    /**
     * removeSending :
     * @param element 
     */

     void removeSending(String element);

    /**
     * clearSending :
     */

     void clearSending();


} //Session
